# music-geometry-eval
A python library to automatically evaluate music tonality based on geometry

Implementation of the tonality metrics based in geometry from:

Tymoczko, D. (2011). A geometry of music : harmony and counterpoint in the extended common practice. Oxford University Press. Retrieved from https://books.google.com.co/books/about/A_Geometry_of_Music.html?id=1Jpq5BRLCNoC&redir_esc=y

See the library in PyPI: [https://pypi.python.org/pypi/music-geometry-eval](https://pypi.python.org/pypi/music-geometry-eval)

Intall it with:
```
pip install music_geometry_eval
```
